@@ -6,10 +6,10 @@
 	Process::Process()
 	{
 		_buffer = TQString();
-		_process = new KProcess();
+		_process = new TDEProcess();
 	
-		connect(_process, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)),
-			this, TQT_SLOT(slotProcessOutput(KProcess*, char*, int)));
+		connect(_process, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
+			this, TQT_SLOT(slotProcessOutput(TDEProcess*, char*, int)));
 	
 	}
 	
@@ -32,9 +32,9 @@
 	void Process::start(bool block)
 	{
 		if( block )
-			_process->start(KProcess::Block, KProcess::Stdout);
+			_process->start(TDEProcess::Block, TDEProcess::Stdout);
 		else
-			_process->start(KProcess::DontCare, KProcess::Stdout);
+			_process->start(TDEProcess::DontCare, TDEProcess::Stdout);
 	}
 	
 	TQString Process::getBuffer()
@@ -52,7 +52,7 @@
 		return _process->normalExit();
 	}
 	
-	void Process::slotProcessOutput(KProcess* process, char* buffer, int len)
+	void Process::slotProcessOutput(TDEProcess* process, char* buffer, int len)
 	{
 		if (process != _process) return;
 	
